**********************************
* Esarey and Chirillo Women & Corruption Paper
* Create Dataset
* March 2, 2013
**********************************

clear all
set mem 200m
set more off

**************************************************
* Convert Women in Parliament Data to Stata Format
**************************************************

clear
insheet using "wominpar.csv"
sort cname year
replace ccode = ccode[_n-1] if ccode==.
sort ccode year
save wominpar.dta, replace


**************************************************
* Convert World Bank Governance Indicators to Stata Format
**************************************************

clear
insheet using "wbgi_data.csv"
rename code ccodewb
rename country wbgi_cname
rename est wbgi_corr_n
rename rank wbgi_corank_n
sort ccodewb year

save wbgi_data.dta, replace

**************************************************
** prepare CIRI human rights dataset
**************************************************

clear
insheet using "ciri_raw_09.csv"
rename cow ccodecow
drop if ccodecow==.
sort ccodecow year
save ciri_raw_09, replace

**************************************************
** prepare economic freedom data
**************************************************

clear
insheet using "ec_freedom3.csv"
sort cname year
replace ccode = ccode[_n-1] if ccode==.
drop if ccode>=9000|ccode==.
sort ccode year
save ecfreedom3.dta, replace

**************************************************
** prepare ICRG dataset
**************************************************

clear
insheet using "icrg_polrisk_data.csv"
sort country year
bysort country: replace ccode = ccode[_n-1] if ccode==.
sort ccode year
save icrg_polrisk_data.dta, replace


**************************************************
** prepare WVS dataset
**************************************************

clear 
set mem 500m
use wvs.dta
keep if s002==4|s002==5
gen malebribe=.
replace malebribe=f117 if x001==1
gen femalebribe=.
replace femalebribe=f117 if x001==2
collapse malebribe femalebribe, by(s003)
rename s003 ccode
sort ccode
save wvs_bribegender.dta, replace



**************************************************
** merge all the above into the QoG data
**************************************************


* Open the QoG Dataset
use "QoG_t_s_v17June09.dta"
set more off

* Merge in women in parliament data
sort ccode year
merge ccode year using wominpar.dta, uniqusing
*look at what we did
tab _merge
list cname if _merge==2
tab year if _merge==1
list cname year if(_merge==1 & year>=1998)
drop if _merge ==2
drop _merge

* Merge in WBGI Corruption indicator
drop if ccodewb==""
sort ccodewb year
merge ccodewb year using "wbgi_data.dta", uniqusing
*look at what we did
tab _merge
list wbgi_cname if _merge==2
tab year if _merge==1
sort cname year
list cname year if(_merge==1 & year>=1998)
drop if _merge ==2
drop _merge

*sort on the merge variables for CIRI
sort ccodecow year
merge ccodecow year using ciri_raw_09, uniqusing
tab _merge
drop if _merge==2
drop _merge
*properly code some CIRI variables
replace wopol = . if wopol<0
replace wecon = . if wecon<0
replace assn = . if assn<0
replace polpris = . if polpris<0

*sort on the merge variables for economic freedom
sort ccode year
merge ccode year using ecfreedom3, uniqusing
tab _merge
drop if _merge==2
drop _merge

* Merge in ICRG
sort ccode year
merge ccode year using icrg_polrisk_data, uniqusing
tab _merge
*list cname year if _merge==1
*list country year if _merge==2 & year>=1998
drop if _merge==2
drop _merge

* Merge in World Values Survey bribe stats
sort ccode
merge ccode using wvs_bribegender, uniqusing
tab _merge
*list cname year if _merge==1
*list country year if _merge==2 & year>=1998
drop if _merge==2
drop _merge
set more off





keep if year>=1998

save esarey_chirillo_replication.dta, replace
