************
* Esarey/Chirillo Corruption and Gender Replication File
* 5/2/2013
************

clear all
set more off
use esarey_chirillo_replication.dta, replace

log using esarey_chirillo_log.smcl, replace

gen ln_gdpc = log(unna_gdpc)
gen ln_pop = log(unna_pop)

* create an overall women in parliament measure
* and use that for the analysis

gen pwom_tot = (womseat_lh+womseat_uh)/(lh_seats+uh_seats)

*fill in some missing values in the total women in parliament data
xi: impute pwom_tot p_polity2 assn polpris  wopol wecon ln_gdpc unna_otco ln_pop i.ht_region i.year, gen(pwom_tot_i)
replace pwom_tot_i=0 if pwom_tot_i<0

gen wopolXtot_i = pwom_tot_i * wopol
gen weconlXtot_i = pwom_tot_i * wecon
gen polityXtot_i = pwom_tot_i*p_polity2

*generate new economic freedom index
gen hf_efi_n=(business_freedom+fiscal_freedom+govsize+monetary_freedom+investment_freedom+financial_freedom)/6

*try to impute EFI for missing countries
xi: impute hf_efi_n p_polity2 ln_pop ln_gdpc i.ht_region i.year, gen(hf_efi_i)


*
* Table 2 Column 1
*****************************
xi: regress wbgi_corr_n pwom_tot_i p_polity2 polityXtot_i wopol wecon ln_gdpc ln_pop unna_otco hf_efi_i i.ht_region i.year, robust 

unique cname if e(sample)
tab year if e(sample)


*
* Table 2 Column 2
*****************************
xi: regress wbgi_corr_n pwom_tot_i p_polity2 wopol wecon ln_gdpc ln_pop unna_otco hf_efi_i i.ht_region i.year, robust 

* 
* Footnote 6: how corrupt is India?
************************************
by year, sort: egen N = count(wbgi_cce) if(e(sample))
by year: egen i = rank(wbgi_cce) if(e(sample)), track 
gen pcrank = (i - 1) / (N - 1) if(e(sample))
sort year pcrank
list pcrank cname if year==2004 & e(sample)
list pcrank cname if year==2004 & cname=="India"

*
* Figure 2a and 2b
******************************
twoway (scatter wbgi_corr_n pwom_tot_i if(p_polity2>0)) (lfit wbgi_corr_n pwom_tot_i if(p_polity2>0), title("Polity > 0") xtitle("Percentage of Women in Parliament") legend( order(1 "WBGI Control of Corruption Index" 2 "Fitted Values")) )
twoway (scatter wbgi_corr_n pwom_tot_i if(p_polity2<=0)) (lfit wbgi_corr_n pwom_tot_i if(p_polity2<=0), title("Polity <= 0") xtitle("Percentage of Women in Parliament") legend( order(1 "WBGI Control of Corruption Index" 2 "Fitted Values")) )


reg wbgi_corr_n pwom_tot_i if(p_polity2<=0), robust
reg wbgi_corr_n pwom_tot_i if(p_polity2>0), robust

* gender gap variable for attitudes toward bribery
gen bribedif = malebribe-femalebribe

*
* Figure 1
*******************************
twoway (scatter bribedif p_polity2 if(year==2002 & bribedif>-.3 & bribedif<.4)) (lfit bribedif p_polity2 if(year==2002  & bribedif>-.3 & bribedif<.4), xtitle("Revised Combined Polity Score") legend( order(1 "Gender Gap in Corruption Tolerance" 2 "Fitted Values")) )

*
* Table 1, Column 1
*************************
xi: regress bribedif p_polity2 wecon wopol ln_gdpc ln_pop if(year==2002 & bribedif>-.3 & bribedif<.4), vce(hc3)
summarize bribedif if e(sample)
est store yr02

xi: regress bribedif p_polity2 wecon wopol ln_gdpc ln_pop if(year==2002), vce(hc3)
list cname if e(sample) & (bribedif<-.3 | bribedif>.4)

* try other years - 1999
xi: regress bribedif p_polity2 wecon wopol ln_gdpc ln_pop if(year==1999 & bribedif>-.3 & bribedif<.4), vce(hc3)
est store yr99
* try other years - 2000
xi: regress bribedif p_polity2 wecon wopol ln_gdpc ln_pop if(year==2000 & bribedif>-.3 & bribedif<.4), vce(hc3)
est store yr00
* try other years - 2001
xi: regress bribedif p_polity2 wecon wopol ln_gdpc ln_pop if(year==2001 & bribedif>-.3 & bribedif<.4), vce(hc3)
est store yr01

est table yr99 yr00 yr01 yr02, se


*
* Figure 3
* Code stolen with love from Brambor, Clark, and Golder (2006)
* (all other ME plots come from the same source)
*****************************************************************

xi: regress wbgi_corr_n pwom_tot_i p_polity2 polityXtot_i wopol wecon ln_gdpc ln_pop unna_otco hf_efi_i i.ht_region i.year, robust


*     ****************************************************************  *
*       Generate the values of Z for which you want to calculate the    *
*       marginal effect (and standard errors) of X on Y.                *
*     ****************************************************************  *

generate MV=((_n-1)/10)-10

replace  MV=. if _n>200

*     ****************************************************************  *
*       Grab elements of the coefficient and variance-covariance matrix *
*       that are required to calculate the marginal effect and standard *
*       errors.                                                         *
*     ****************************************************************  *

matrix b=e(b) 
matrix V=e(V)
 
scalar b1=b[1,1] 
scalar b2=b[1,2]
scalar b3=b[1,3]


scalar varb1=V[1,1] 
scalar varb2=V[2,2] 
scalar varb3=V[3,3]

scalar covb1b3=V[1,3] 
scalar covb2b3=V[2,3]

scalar list b1 b2 b3 varb1 varb2 varb3 covb1b3 covb2b3

*     ****************************************************************  *
*       Calculate the marginal effect of X on Y for all MV values of    *
*       the modifying variable Z.                                       *
*     ****************************************************************  *

gen conb=b1+b3*MV if _n<200


*     ****************************************************************  *
*       Calculate the standard errors for the marginal effect of X on Y *
*       for all MV values of the modifying variable Z.                  *
*     ****************************************************************  *

gen conse=sqrt(varb1+varb3*(MV^2)+2*covb1b3*MV) if _n<200


*     ****************************************************************  *
*       Generate upper and lower bounds of the confidence interval.     *
*       Specify the significance of the confidence interval.            *
*     ****************************************************************  *

gen a=1.96*conse
 
gen upper=conb+a
 
gen lower=conb-a

*     ****************************************************************  *
*       Graph the marginal effect of X on Y across the desired range of *
*       the modifying variable Z.  Show the confidence interval.        *
*     ****************************************************************  *

graph twoway line conb   MV, clwidth(medium) clcolor(blue) clcolor(black) ||   line upper  MV, clpattern(dash) clwidth(thin) clcolor(black) ||   line lower  MV, clpattern(dash) clwidth(thin) clcolor(black) ||   ,   xlabel(-10 -9 -8 -7 -6 -5 -4 -3 -2 -1 0 1 2 3 4 5 6 7 8 9 10, labsize(2.5))  ylabel(-2 -1 0 1 2,   labsize(2.5)) yscale(noline) xscale(noline) legend(col(1) order(1 2) label(1 "Marginal Effect of % Wom. in Parliament") label(2 "95% Confidence Interval") label(3 " ")) yline(0, lcolor(black)) title("Marginal Effect of Women in Parliament" "on the Control of Corruption As Polity Changes", size(4)) subtitle(" " "Dependent Variable: WBGI Control of Corruption" " ", size(3)) xtitle( "Polity Score", size(3)  ) xsca(titlegap(2)) ysca(titlegap(2)) ytitle("Marginal Effect of Women in Parliament", size(3)) scheme(s2mono) graphregion(fcolor(white))

drop MV conb conse a upper lower




*
* Figure 4b
****************


xi: regress icrg_corruption pwom_tot_i p_polity2 polityXtot_i wopol wecon ln_gdpc ln_pop unna_otco hf_efi_i i.ht_region i.year, robust 


*     ****************************************************************  *
*       Generate the values of Z for which you want to calculate the    *
*       marginal effect (and standard errors) of X on Y.                *
*     ****************************************************************  *

generate MV=((_n-1)/10)-10

replace  MV=. if _n>200

*     ****************************************************************  *
*       Grab elements of the coefficient and variance-covariance matrix *
*       that are required to calculate the marginal effect and standard *
*       errors.                                                         *
*     ****************************************************************  *

matrix b=e(b) 
matrix V=e(V)
 
scalar b1=b[1,1] 
scalar b2=b[1,2]
scalar b3=b[1,3]


scalar varb1=V[1,1] 
scalar varb2=V[2,2] 
scalar varb3=V[3,3]

scalar covb1b3=V[1,3] 
scalar covb2b3=V[2,3]

scalar list b1 b2 b3 varb1 varb2 varb3 covb1b3 covb2b3

*     ****************************************************************  *
*       Calculate the marginal effect of X on Y for all MV values of    *
*       the modifying variable Z.                                       *
*     ****************************************************************  *

gen conb=b1+b3*MV if _n<200


*     ****************************************************************  *
*       Calculate the standard errors for the marginal effect of X on Y *
*       for all MV values of the modifying variable Z.                  *
*     ****************************************************************  *

gen conse=sqrt(varb1+varb3*(MV^2)+2*covb1b3*MV) if _n<200


*     ****************************************************************  *
*       Generate upper and lower bounds of the confidence interval.     *
*       Specify the significance of the confidence interval.            *
*     ****************************************************************  *

gen a=1.96*conse
 
gen upper=conb+a
 
gen lower=conb-a

*     ****************************************************************  *
*       Graph the marginal effect of X on Y across the desired range of *
*       the modifying variable Z.  Show the confidence interval.        *
*     ****************************************************************  *

graph twoway line conb   MV, clwidth(medium) clcolor(blue) clcolor(black) ||   line upper  MV, clpattern(dash) clwidth(thin) clcolor(black) ||   line lower  MV, clpattern(dash) clwidth(thin) clcolor(black) ||   ,   xlabel(-10 -9 -8 -7 -6 -5 -4 -3 -2 -1 0 1 2 3 4 5 6 7 8 9 10, labsize(2.5))  ylabel(-2 -1 0 1 2 3 4,   labsize(2.5)) yscale(noline) xscale(noline) legend(col(1) order(1 2) label(1 "Marginal Effect of % Wom. in Parliament") label(2 "95% Confidence Interval") label(3 " ")) yline(0, lcolor(black)) title("Marginal Effect of Women in Parliament" "on the Control of Corruption As Polity Changes", size(4)) subtitle(" " "Dependent Variable: ICRG Score" " ", size(3)) xtitle( "Polity Score", size(3)  ) xsca(titlegap(2)) ysca(titlegap(2)) ytitle("Marginal Effect of Women in Parliament", size(3)) scheme(s2mono) graphregion(fcolor(white))

drop MV conb conse a upper lower




*
* Figure 4c
****************
xi: regress ti_cpi pwom_tot_i p_polity2 polityXtot_i wopol wecon ln_gdpc ln_pop unna_otco hf_efi_i i.ht_region i.year, robust 


*     ****************************************************************  *
*       Generate the values of Z for which you want to calculate the    *
*       marginal effect (and standard errors) of X on Y.                *
*     ****************************************************************  *

generate MV=((_n-1)/10)-10

replace  MV=. if _n>200

*     ****************************************************************  *
*       Grab elements of the coefficient and variance-covariance matrix *
*       that are required to calculate the marginal effect and standard *
*       errors.                                                         *
*     ****************************************************************  *

matrix b=e(b) 
matrix V=e(V)
 
scalar b1=b[1,1] 
scalar b2=b[1,2]
scalar b3=b[1,3]


scalar varb1=V[1,1] 
scalar varb2=V[2,2] 
scalar varb3=V[3,3]

scalar covb1b3=V[1,3] 
scalar covb2b3=V[2,3]

scalar list b1 b2 b3 varb1 varb2 varb3 covb1b3 covb2b3

*     ****************************************************************  *
*       Calculate the marginal effect of X on Y for all MV values of    *
*       the modifying variable Z.                                       *
*     ****************************************************************  *

gen conb=b1+b3*MV if _n<200


*     ****************************************************************  *
*       Calculate the standard errors for the marginal effect of X on Y *
*       for all MV values of the modifying variable Z.                  *
*     ****************************************************************  *

gen conse=sqrt(varb1+varb3*(MV^2)+2*covb1b3*MV) if _n<200


*     ****************************************************************  *
*       Generate upper and lower bounds of the confidence interval.     *
*       Specify the significance of the confidence interval.            *
*     ****************************************************************  *

gen a=1.96*conse
 
gen upper=conb+a
 
gen lower=conb-a

*     ****************************************************************  *
*       Graph the marginal effect of X on Y across the desired range of *
*       the modifying variable Z.  Show the confidence interval.        *
*     ****************************************************************  *

graph twoway line conb   MV, clwidth(medium) clcolor(blue) clcolor(black) ||   line upper  MV, clpattern(dash) clwidth(thin) clcolor(black) ||   line lower  MV, clpattern(dash) clwidth(thin) clcolor(black) ||   ,   xlabel(-10 -9 -8 -7 -6 -5 -4 -3 -2 -1 0 1 2 3 4 5 6 7 8 9 10, labsize(2.5))  ylabel(-2 -1 0 1 2 3 4 5,   labsize(2.5)) yscale(noline) xscale(noline) legend(col(1) order(1 2) label(1 "Marginal Effect of % Wom. in Parliament") label(2 "95% Confidence Interval") label(3 " ")) yline(0, lcolor(black)) title("Marginal Effect of Women in Parliament" "on the Control of Corruption As Polity Changes", size(4)) subtitle(" " "Dependent Variable: Transparency International Corruption Perception Index" " ", size(3)) xtitle( "Polity Score", size(3)  ) xsca(titlegap(2)) ysca(titlegap(2)) ytitle("Marginal Effect of Women in Parliament", size(3)) scheme(s2mono) graphregion(fcolor(white))

drop MV conb conse a upper lower














*****
* VanHanen Democratization Index Substitution
*****

clear all
use esarey_chirillo_replication.dta, replace

gen ln_gdpc = log(unna_gdpc)
gen ln_pop = log(unna_pop)

* create an overall women in parliament measure
* and use that for the analysis

gen pwom_tot = (womseat_lh+womseat_uh)/(lh_seats+uh_seats)

*fill in some missing values in the total women in parliament data
xi: impute pwom_tot van_index assn polpris  wopol wecon ln_gdpc unna_otco ln_pop i.ht_region i.year, gen(pwom_tot_i)
replace pwom_tot_i=0 if pwom_tot_i<0

gen wopolXtot_i = pwom_tot_i * wopol
gen weconlXtot_i = pwom_tot_i * wecon
gen polityXtot_i = pwom_tot_i*van_index

*generate new economic freedom index
gen hf_efi_n=(business_freedom+fiscal_freedom+govsize+monetary_freedom+investment_freedom+financial_freedom)/6

*try to impute EFI for missing countries
xi: impute hf_efi_n van_index ln_pop ln_gdpc i.ht_region i.year, gen(hf_efi_i)

gen efi_iXtot_i = pwom_tot_i * hf_efi_i
gen efi_iXpolity = van_index * hf_efi_i


* gender gap variable for attitudes toward bribery
gen bribedif = malebribe-femalebribe


*
* Table 1, Column 2
*************************
xi: regress bribedif van_index wecon wopol ln_gdpc ln_pop if(year==2002 & bribedif>-.3 & bribedif<.4), vce(hc3)

xi: regress bribedif van_index wecon wopol ln_gdpc ln_pop if(year==2002), vce(hc3)




*
* Figure 4a
****************


xi: regress wbgi_corr_n pwom_tot_i van_index polityXtot_i wopol wecon ln_gdpc ln_pop unna_otco hf_efi_i i.ht_region i.year, robust


*     ****************************************************************  *
*       Generate the values of Z for which you want to calculate the    *
*       marginal effect (and standard errors) of X on Y.                *
*     ****************************************************************  *

generate MV=_n-1

replace  MV=. if _n>51

*     ****************************************************************  *
*       Grab elements of the coefficient and variance-covariance matrix *
*       that are required to calculate the marginal effect and standard *
*       errors.                                                         *
*     ****************************************************************  *

matrix b=e(b) 
matrix V=e(V)
 
scalar b1=b[1,1] 
scalar b2=b[1,2]
scalar b3=b[1,3]


scalar varb1=V[1,1] 
scalar varb2=V[2,2] 
scalar varb3=V[3,3]

scalar covb1b3=V[1,3] 
scalar covb2b3=V[2,3]

scalar list b1 b2 b3 varb1 varb2 varb3 covb1b3 covb2b3

*     ****************************************************************  *
*       Calculate the marginal effect of X on Y for all MV values of    *
*       the modifying variable Z.                                       *
*     ****************************************************************  *

gen conb=b1+b3*MV if _n<200


*     ****************************************************************  *
*       Calculate the standard errors for the marginal effect of X on Y *
*       for all MV values of the modifying variable Z.                  *
*     ****************************************************************  *

gen conse=sqrt(varb1+varb3*(MV^2)+2*covb1b3*MV) if _n<200


*     ****************************************************************  *
*       Generate upper and lower bounds of the confidence interval.     *
*       Specify the significance of the confidence interval.            *
*     ****************************************************************  *

gen a=1.96*conse
 
gen upper=conb+a
 
gen lower=conb-a

*     ****************************************************************  *
*       Graph the marginal effect of X on Y across the desired range of *
*       the modifying variable Z.  Show the confidence interval.        *
*     ****************************************************************  *

graph twoway line conb   MV, clwidth(medium) clcolor(blue) clcolor(black) ||   line upper  MV, clpattern(dash) clwidth(thin) clcolor(black) ||   line lower  MV, clpattern(dash) clwidth(thin) clcolor(black) ||   ,   xlabel(0 5 10 15 20 25 30 35 40 45 50, labsize(2.5))  ylabel(-2 -1 0 1 2 3,   labsize(2.5)) yscale(noline) xscale(noline) legend(col(1) order(1 2) label(1 "Marginal Effect of % Wom. in Parliament") label(2 "95% Confidence Interval") label(3 " ")) yline(0, lcolor(black)) title("Marginal Effect of Women in Parliament" "on the Control of Corruption As Democratization Changes", size(4)) subtitle(" " "Dependent Variable: WBGI Control of Corruption" " ", size(3)) xtitle( "Democratization Index", size(3)  ) xsca(titlegap(2)) ysca(titlegap(2)) ytitle("Marginal Effect of Women in Parliament", size(3)) scheme(s2mono) graphregion(fcolor(white))

drop MV conb conse a upper lower


log close
